@@ -8,9 +8,9 @@ void Generator::print(ostream &out) const
     key(out);
 
     out << 
-        "    std::cout << \"Token: \" << d_token__;\n"
-        "    if (isprint(d_token__))\n"
+        "    std::cout << \"Token: \" << d_token_;\n"
+        "    if (isprint(d_token_))\n"
         "        std::cout << \" (`\" << "
-                                "static_cast<char>(d_token__) << \"')\";\n"
+                                "static_cast<char>(d_token_) << \"')\";\n"
         "    std::cout << \", matched: `\" << d_matched << \"'\\n\";\n";
 }
