@@ -15,8 +15,7 @@ class Rule: public FlexTypes
 {
     friend std::ostream &operator<<(std::ostream &out, Rule const &rule);
 
-
-    typedef std::pair<size_t, size_t> Pair;     // first/final state nrs.
+    using Pair = std::pair<size_t, size_t>;     // first/final state nrs.
 
     Pattern d_pattern;          // pattern to match for this rule.
                                 // first: States start index, 
